##
##  python.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         python
Summary:      The Python Programming Language
URL:          http://www.python.org/
Vendor:       Guido van Rossum
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Language
License:      GPL
Version:      3.13.3
Release:      20250410

#   package options
%option       with_readline      no
%option       with_db            no
%option       with_dbm           no
%option       with_curses        no
%option       with_zlib          no
%option       with_bzip2         no
%option       with_lzma          no
%option       with_xml           no
%option       with_locale        yes
%option       with_ctypes        yes

#   list of sources
Source0:      http://www.python.org/ftp/python/%{version}/Python-%{version}.tgz
Patch0:       python.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc
PreReq:       OpenPKG, openpkg >= 20160101, gcc
BuildPreReq:  openssl-threads
PreReq:       openssl-threads
BuildPreReq:  zlib
PreReq:       zlib
%if "%{with_readline}" == "yes"
BuildPreReq:  readline
PreReq:       readline
%endif
%if "%{with_db}" == "yes"
BuildPreReq:  db
PreReq:       db
%endif
%if "%{with_dbm}" == "yes"
BuildPreReq:  gdbm::with_ndbm = yes
PreReq:       gdbm::with_ndbm = yes
%endif
%if "%{with_curses}" == "yes"
BuildPreReq:  ncurses
PreReq:       ncurses
%endif
%if "%{with_zlib}" == "yes"
BuildPreReq:  zlib
PreReq:       zlib
%endif
%if "%{with_bzip2}" == "yes"
BuildPreReq:  bzip2
PreReq:       bzip2
%endif
%if "%{with_lzma}" == "yes"
BuildPreReq:  xz
PreReq:       xz
%endif
%if "%{with_xml}" == "yes"
BuildPreReq:  expat
PreReq:       expat
%endif
%if "%{with_locale}" == "yes"
BuildPreReq:  gettext, libiconv
PreReq:       gettext, libiconv
%endif
%if "%{with_ctypes}" == "yes"
BuildPreReq:  libffi
PreReq:       libffi
%endif

%description
    Python is an interpreted, interactive, object-oriented programming
    language. Python combines remarkable power with very clear syntax.
    It has modules, classes, exceptions, very high level dynamic data
    types, and dynamic typing. There are interfaces to many system calls
    and libraries, as well as to various windowing systems (X11, Motif,
    Tk, Mac, MFC). New built-in modules are easily written in C or C++.
    Python is also usable as an extension language for applications that
    need a programmable interface.

%track
    prog python = {
        version   = %{version}
        url       = http://www.python.org/download/source/
        regex     = Python-(\d+(\.\d+)+)\.tgz
    }

%prep
    %setup -q -n Python-%{version}
    %patch -p0

%build
    %{l_shtool} subst \
        -e 's;altinstall bininstall maninstall;altinstall maninstall;' \
        Makefile.pre.in
    echo "" >config.cache
%if "%{with_readline}" == "yes"
    ( echo "readline readline.c %{l_cppflags} %{l_ldflags} -lreadline -ltermcap"
    ) >>Modules/Setup.local
%endif
%if "%{with_db}" == "yes"
    ( echo "_bsddb _bsddb.c %{l_cppflags} %{l_ldflags} -ldb"
    ) >>Modules/Setup.local
%endif
%if "%{with_dbm}" == "yes"
    ( echo "_dbm  _dbmmodule.c  -DHAVE_NDBM_H %{l_cppflags} %{l_ldflags} -lndbm -lgdbm"
      echo "_gdbm _gdbmmodule.c -DHAVE_GDBM_H %{l_cppflags} %{l_ldflags} -lgdbm"
    ) >>Modules/Setup.local
%endif
%if "%{with_curses}" == "yes"
    ( echo "_curses_panel _curses_panel.c %{l_cppflags} %{l_ldflags} -lpanel -lncurses"
    ) >>Modules/Setup.local
%endif
%if "%{with_zlib}" == "yes"
    ( echo "zlib zlibmodule.c %{l_cppflags} %{l_ldflags} -lz"
    ) >>Modules/Setup.local
%endif
%if "%{with_bzip2}" == "yes"
    ( echo "_bz2 _bz2module.c %{l_cppflags} %{l_ldflags} -lbz2"
    ) >>Modules/Setup.local
%endif
%if "%{with_lzma}" == "yes"
    ( echo "_lzma _lzmamodule.c %{l_cppflags} %{l_ldflags} -llzma"
    ) >>Modules/Setup.local
%endif
%if "%{with_xml}" == "yes"
    ( echo "EXPAT_DIR=%{l_prefix}"
      echo "pyexpat pyexpat.c -DHAVE_EXPAT_H %{l_cppflags} %{l_ldflags} -lexpat"
    ) >>Modules/Setup.local
%endif
%if "%{with_locale}" == "yes"
    ( echo "_locale _localemodule.c %{l_cppflags} %{l_ldflags} -lintl -liconv"
    ) >>Modules/Setup.local
%endif
    ( echo "_socket socketmodule.c"
      echo "SSL=%{l_prefix}"
      echo "_ssl _ssl.c -DUSE_SSL -lssl -lcrypto"
    ) >>Modules/Setup.local
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags openssl-threads .} -DOPENSSL_THREADS" \
    CXXFLAGS="%{l_cxxflags -O}" \
    LDFLAGS="%{l_ldflags openssl-threads .}" \
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --without-ensurepip \
        --enable-optimizations
    %{l_make} %{l_mflags}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    rm -f  $RPM_BUILD_ROOT%{l_prefix}/bin/smtpd.py
    rm -f  $RPM_BUILD_ROOT%{l_prefix}/bin/pyvenv
    rm -f  $RPM_BUILD_ROOT%{l_prefix}/bin/idle
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/lib/python*/test
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/python*/site-packages/setuptools/script*dev*.tmpl
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/python*/site-packages/setuptools/command/launcher*manifest.xml
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    ln  $RPM_BUILD_ROOT%{l_prefix}/bin/python3 \
        $RPM_BUILD_ROOT%{l_prefix}/bin/python
    ln  $RPM_BUILD_ROOT%{l_prefix}/bin/python3-config \
        $RPM_BUILD_ROOT%{l_prefix}/bin/python-config
    ln  $RPM_BUILD_ROOT%{l_prefix}/man/man1/python3.*.* \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1/python
    ( cd $RPM_BUILD_ROOT%{l_prefix}/lib && ln -s python3.* python ) || exit $?
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

